@@ -52,7 +52,7 @@ class HeaderToLabelMiddleware(object):
 
     def process_request(self, request):
         self._initial_http_body = request.body
-        self._request_start_time = self.__get_time_in_milliseconds()
+        self._request_start_time = str(self.__get_time_in_milliseconds())
         log_label_request_settings = getattr(settings, LOG_LABEL_REQUEST_SETTING, dict())
 
         nim_headers = Utils.get_nim_headers(request)
@@ -69,7 +69,7 @@ class HeaderToLabelMiddleware(object):
         log_entry_debug = dict(
             nim_headers=nim_headers,
             request_start_time_ms=self._request_start_time,
-            request_end_time_ms=self.__get_time_in_milliseconds(),
+            request_end_time_ms=str(self.__get_time_in_milliseconds()),
             method=request.method,
             body=Utils.adjust_string_length(self._initial_http_body, getattr(settings, MAX_REQUEST_RESPONSE_SIZE)),
             tags=dict(
@@ -93,11 +93,11 @@ class HeaderToLabelMiddleware(object):
         log_entry = dict(
             nim_headers=nim_headers,
             request_start_time_ms=self._request_start_time,
-            request_end_time_ms=self.__get_time_in_milliseconds(),
+            request_end_time_ms=str(self.__get_time_in_milliseconds()),
             method=request.method,
             body=Utils.adjust_string_length(self._initial_http_body,
                                             getattr(settings, MAX_REQUEST_RESPONSE_SIZE)) if response.status_code < 400 else self._initial_http_body,
-            status_code=response.status_code,
+            status_code=str(response.status_code),
             response=Utils.adjust_string_length(response.content,
                                                 settings.MAX_REQUEST_RESPONSE_SIZE) if response.status_code < 400 else response.content,
             tags=dict(
@@ -108,8 +108,8 @@ class HeaderToLabelMiddleware(object):
         log_entry_info = dict(
             nim_headers=nim_headers,
             request_start_time_ms=self._request_start_time,
-            request_end_time_ms=self.__get_time_in_milliseconds(),
-            status_code=response.status_code,
+            request_end_time_ms=str(self.__get_time_in_milliseconds()),
+            status_code=str(response.status_code),
             method=request.method,
             tags=dict(
                 url=request.build_absolute_uri()
@@ -141,10 +141,10 @@ class HeaderToLabelMiddleware(object):
         log_entry = dict(
             nim_headers=nim_headers,
             request_start_time_ms=self._request_start_time,
-            request_end_time_ms=self.__get_time_in_milliseconds(),
+            request_end_time_ms=str(self.__get_time_in_milliseconds()),
             method=request.method,
             body=Utils.adjust_string_length(self._initial_http_body, getattr(settings, MAX_REQUEST_RESPONSE_SIZE)),
-            status_code=500,
+            status_code="500",
             exception=str(exception),
             tags=dict(
                 url=request.build_absolute_uri()
@@ -155,8 +155,8 @@ class HeaderToLabelMiddleware(object):
         log_entry_info = dict(
             nim_headers=nim_headers,
             request_start_time_ms=self._request_start_time,
-            request_end_time_ms=self.__get_time_in_milliseconds(),
-            status_code=500,
+            request_end_time_ms=str(self.__get_time_in_milliseconds()),
+            status_code="500",
             method=request.method,
             tags=dict(
                 url=request.build_absolute_uri()
@@ -174,4 +174,7 @@ class HeaderToLabelMiddleware(object):
         logger.info(
             '', extra=log_entry_info
         )
+        logger.debug(
+            '', extra={"Hello": ":-)"}
+        )
         return exception
